.. module:: swiftest

Swiftest
========

Swiftest is a software packaged designed to model the long-term dynamical dynamics of n-body systems with a dominant central body, 
like the solar system. 


**Useful links**:
`Home <https://swiftest.readthedocs.io/en/latest/>`__ |
`Code Repository <https://github.com/profminton/swiftest>`__ |
`Issues <https://github.com/profminton/swiftest/issues>`__ |
`Discussions <https://github.com/profminton/swiftest/discussions>`__ |
`Releases <https://github.com/profminton/swiftest/releases>`__ |


.. grid:: 1 1 2 2
    :gutter: 2

    .. grid-item-card:: Getting started
        :img-top: _static/index_getting_started.svg
        :link: getting-started-guide/index
        :link-type: doc

        New to *swiftest*? Check out the getting started guides. They contain an
        introduction to *Swiftest's* main concepts and links to additional tutorials.

    .. grid-item-card::  User guide
        :img-top: _static/index_user_guide.svg
        :link: user-guide/index
        :link-type: doc

        The user guide provides in-depth information on the
        key concepts of Swiftest with useful background information and explanation.

    .. grid-item-card::  API reference
        :img-top: _static/index_api_reference.svg
        :link: api
        :link-type: doc

        The reference guide contains a detailed description of the Swiftest API.
        The reference describes how the methods work and which parameters can
        be used. It assumes that you have an understanding of the key concepts.

    .. grid-item-card::  Developer guide
        :img-top: _static/index_contribute.svg
        :link: contributing
        :link-type: doc

        Saw a typo in the documentation? Want to improve existing functionalities?
        The contributing guidelines will guide you through the process of improving
        Swiftest.

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For users

   Getting Started <getting-started-guide/index>
   User Guide <user-guide/index>
   API Reference <api>

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For developers/contributors

   Contributing Guide <contributing>
   What’s New <whats-new>
   GitHub repository <https://github.com/profminton/swiftest>

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Community

   GitHub discussions <https://github.com/profminton/swiftest/discussions>
